/*
 * $Id: main.c,v 1.1 2001/12/03 04:20:06 bsulcer Exp $
 * Copyright (c) 2001 Brian Sulcer <bsulcer@pobox.com>
 *
 * This file is part of Not One for PalmOS.
 *
 * Not One for PalmOS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * Not One for PalmOS is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Not One for PalmOS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#include <PalmOS.h>
#include "constants.h"
#include "resources.h"
#include "utils.h"
#include "mainform.h"
#include "prefs.h"
#include "game.h"

static Boolean AppHandleEvent(EventPtr event)
{
  UInt16 formId;
  FormPtr form;

  if (event->eType == frmLoadEvent) {
    // Load the form resource.
    formId = event->data.frmLoad.formID;
    form = FrmInitForm(formId);
    ErrFatalDisplayIf(!form, "Can't initialize form");
    FrmSetActiveForm(form);

    // Set the event handler for the form.  The handler of the currently
    // active form is called by FrmHandleEvent each time is receives an
    // event.
    switch (formId) {
    case MainForm:
      FrmSetEventHandler(form, MainFormHandleEvent);
      break;

    default:
      ErrFatalDisplay("Invalid Form Load Event");
      break;

    }
    return true;
  } else 
    return false;
}


static 
void AppEventLoop(void)
{
  Err error;
  EventType event;

  do {
    EvtGetEvent(&event, evtWaitForever);
    
    if (! SysHandleEvent(&event))
      if (! MenuHandleEvent(0, &event, &error))
        if (! AppHandleEvent(&event))
          FrmDispatchEvent(&event);

  } while (event.eType != appStopEvent);
}


static 
Err AppStart(void)
{
  LoadPrefs();
  return errNone;
}


static 
void AppStop(void)
{
  SavePrefs();
  FrmCloseAllForms();
}



UInt32 PilotMain(UInt16 launchCode, MemPtr launchParameters, 
		 UInt16 launchFlags)
{
  Err error;

  switch (launchCode) {
  case sysAppLaunchCmdNormalLaunch:
    error = RomVersionCompatible (kOurMinVersion, launchFlags);
    if (error) 
      return error;
    error = AppStart();
    if (error) 
      return error;
      
    FrmGotoForm(MainForm);
    AppEventLoop();
    AppStop();
    break;

  default:
    break;
  }
  
  return errNone;
}


