/*
 * $Id: mainform.c,v 1.1 2001/12/03 04:20:06 bsulcer Exp $
 * Copyright (c) 2001 Brian Sulcer <bsulcer@pobox.com>
 *
 * This file is part of Not One for PalmOS.
 *
 * Not One for PalmOS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * Not One for PalmOS is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Not One for PalmOS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#include <PalmOS.h>
#include "constants.h"
#include "resources.h"
#include "mainform.h"
#include "game.h"
#include "utils.h"

static char roundLabel[3] = "";
static char die1Label[2] = "";
static char die2Label[2] = "";
static char roundTotalLabel[11] = "";
static char firstRollLabel[3] = "";
static char *turnLabels[2] = { "Your Turn", "Palms Turn" };
static char playerScoreLabel[11] = "";
static char palmScoreLabel[11] = "";

void MainFormInit(FormPtr form)
{
  // warning-- don't do any drawing in this routine.
  // Also, don't call FrmSetFocus from here (it must be called *after*
  // FrmDrawForm)

  if (round == 0) {
    NewGame();
  }
}

static 
void MainFormDeinit(FormPtr form)
{
}

static
void MainFormRefresh()
{
  FormPtr form;
  ControlPtr ctl;
  FieldPtr field;

  form = FrmGetActiveForm();

  if (round > 0) {
    StrIToA(roundLabel, round);
    field = GetObjectPtr(form, RoundField);
    FldSetTextPtr(field, roundLabel);
    FldDrawField(field);

    StrIToA(playerScoreLabel, playerScore);
    field = GetObjectPtr(form, PlayerScoreField);
    FldSetTextPtr(field, playerScoreLabel);
    FldDrawField(field);

    StrIToA(palmScoreLabel, palmScore);
    field = GetObjectPtr(form, PalmScoreField);
    FldSetTextPtr(field, palmScoreLabel);
    FldDrawField(field);

    field = GetObjectPtr(form, TurnField);
    FldSetTextPtr(field, turnLabels[turn]);
    FldDrawField(field);
  }

  if (firstRoll > 0) {
    StrIToA(firstRollLabel, firstRoll);
    field = GetObjectPtr(form, FirstRollField);
    FldSetTextPtr(field, firstRollLabel);
    FrmShowObject(form, FrmGetObjectIndex(form, FirstRollLabel));
    FrmShowObject(form, FrmGetObjectIndex(form, FirstRollField));

    StrIToA(roundTotalLabel, roundTotal);
    field = GetObjectPtr(form, RoundTotalField);
    FldSetTextPtr(field, roundTotalLabel);
    FrmShowObject(form, FrmGetObjectIndex(form, RoundTotalLabel));
    FrmShowObject(form, FrmGetObjectIndex(form, RoundTotalField));
  }
  else {
    FrmHideObject(form, FrmGetObjectIndex(form, FirstRollLabel));
    FrmHideObject(form, FrmGetObjectIndex(form, FirstRollField));
    FrmHideObject(form, FrmGetObjectIndex(form, RoundTotalLabel));
    FrmHideObject(form, FrmGetObjectIndex(form, RoundTotalField));
  }

  if ((die1 > 0) && (die2 > 0)) {
    StrIToA(die1Label, die1);
    ctl = GetObjectPtr(form, Die1Button);
    CtlSetLabel(ctl, die1Label);

    StrIToA(die2Label, die2);
    ctl = GetObjectPtr(form, Die2Button);
    CtlSetLabel(ctl, die2Label);

    FrmShowObject(form, FrmGetObjectIndex(form, Die1Button));
    FrmShowObject(form, FrmGetObjectIndex(form, Die2Button));
  }
  else {
    FrmHideObject(form, FrmGetObjectIndex(form, Die1Button));
    FrmHideObject(form, FrmGetObjectIndex(form, Die2Button));
  }

}

static void DoComputerTurn() {
  RollDice();
  MainFormRefresh();

  while (ComputerWillRoll()) {
    RollDice();
    MainFormRefresh();

    if (roundTotal == 0) {
      FrmAlert(NoPointsPalmAlert);
      break;
    }

    SysTaskDelay(kComputerPlayDelay);
  }

  EndTurn();
  MainFormRefresh();
}

static void DoEndGame() {
  if (round > 10) {
    if (playerScore > palmScore) {
      FrmAlert(PlayerWinsAlert);
    }
    else {
      FrmAlert(PalmWinsAlert);
    }
    NewGame();
    MainFormRefresh();
  }
}

Boolean MainFormHandleEvent(EventPtr event)
{
  Boolean handled = false;
  FormPtr form;

  switch (event->eType) 
  {
  case frmOpenEvent:
    form = FrmGetActiveForm();
    MainFormInit(form);
    FrmDrawForm(form);
    MainFormRefresh();
    // here's where you'd add a call to FrmSetFocus
    handled = true;
    break;

  case frmCloseEvent:
    MainFormDeinit(FrmGetActiveForm());
    handled = false;
    break;
            
  case ctlSelectEvent:
  switch (event->data.ctlSelect.controlID) {
    case RollButton:
      RollDice();
      MainFormRefresh();

      if (roundTotal == 0) {
	FrmAlert (NoPointsPlayerAlert);
	EndTurn();
	DoComputerTurn();
      }

      DoEndGame();
      
      handled = true;
      break;
        
    case EndTurnButton:
      EndTurn();
      MainFormRefresh();

      DoComputerTurn();

      DoEndGame();

      handled = true;
      break;
    }
    break;

  case menuEvent:
    switch (event->data.menu.itemID) {
    case NewCmd:
      NewGame();
      MainFormRefresh();
      handled = true;
      break;
    case InstructionsCmd:
      FrmHelp(InstructionsStr);
      handled = true;
      break;
    case AboutCmd:
      DoDialog(AboutForm);
      handled = true;
      break;
    }
    break;

  default:
    break;
  }  
  return handled;
}

