/*
 * $Id: utils.c,v 1.1 2001/12/03 04:20:06 bsulcer Exp $
 * Copyright (c) 2001 Brian Sulcer <bsulcer@pobox.com>
 *
 * This file is part of Not One for PalmOS.
 *
 * Not One for PalmOS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * Not One for PalmOS is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Not One for PalmOS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#include <PalmOS.h>
#include "utils.h"
#include "resources.h"

Err RomVersionCompatible(UInt32 requiredVersion, UInt16 launchFlags)
{
  UInt32 romVersion;

  // See if we're on in minimum required version of the ROM or later.
  FtrGet(sysFtrCreator, sysFtrNumROMVersion, &romVersion);
  if (romVersion < requiredVersion) {
    UInt16 safeToCallAlertFlags;
    
    safeToCallAlertFlags = 
      sysAppLaunchFlagNewGlobals | sysAppLaunchFlagUIApp;
    if ((launchFlags & (safeToCallAlertFlags)) == safeToCallAlertFlags) {
      FrmAlert (RomIncompatibleAlert);
    
      // Pilot 1.0 will continuously relaunch this app unless we switch to 
      // another safe one.
      if (romVersion < sysMakeROMVersion(2,0,0,sysROMStageRelease,0))
        AppLaunchWithCommand(sysFileCDefaultApp, 
          sysAppLaunchCmdNormalLaunch, NULL);
    }
    
    return (sysErrRomIncompatible);
  }

  return errNone;
}

void *GetObjectPtr(FormPtr form, UInt16 objectID)
{
  return FrmGetObjectPtr(form, FrmGetObjectIndex(form, objectID));
}

void *GetObjectPtrFromActiveForm(UInt16 objectID)
{
  return GetObjectPtr(FrmGetActiveForm(), objectID);
}

UInt16 DoDialog(UInt16 formId)
{
  FormPtr prevFormPtr = FrmGetActiveForm();
  FormPtr currFormPtr = FrmInitForm(formId);
  UInt16 hitButton;

  FrmSetActiveForm(currFormPtr);
  hitButton = FrmDoDialog(currFormPtr);
  if (prevFormPtr != 0) {
    FrmSetActiveForm(prevFormPtr);
  }
  FrmDeleteForm(currFormPtr);

  return hitButton;
}
